<?php

/*
 * This file is part of the Fxp Composer Asset Plugin package.
 *
 * (c) François Pluchino <francois.pluchino@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Fxp\Composer\AssetPlugin\Repository;

use Composer\Repository\RepositoryManager;
use Fxp\Composer\AssetPlugin\Util\AssetPlugin;

/**
 * Factory for custom npm repositories (like verdaccio).
 *
 */
class CustomNpmRegistryFactory implements RegistryFactoryInterface
{
    /**
     * {@inheritdoc}
     */
    public static function create(RepositoryManager $rm, VcsPackageFilter $filter, array $extra)
    {
        if (!array_key_exists('asset-custom-npm-registries', $extra)
            || !is_array($extra['asset-custom-npm-registries'])
        ) {
            return;
        }

        $registries = $extra['asset-custom-npm-registries'];

        foreach ($registries as $registryName => $registryUrl) {
            $config                   = AssetPlugin::createRepositoryConfig($rm, $filter, $extra, $registryName);
            $config['custom_npm_url'] = $registryUrl;
            
            $rm->setRepositoryClass($registryName, 'Fxp\Composer\AssetPlugin\Repository\CustomNpmRepository');
            $rm->addRepository($rm->createRepository($registryName, $config));
        }
    }
}
